@@ -1,20 +1,8 @@
-/*******************************************************************************
-  Copyright 2008 Ian Wadham <iandw.au@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2008 Ian Wadham <iandw.au@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-*******************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "movetracker.h"
 
@@ -98,7 +86,7 @@ void MoveTracker::trackCubeRotation (int sceneID, const QList<CubeView *> &cubeV
 	    // Else, add the rotation to the quaternion and the OpenGL matrix.
 	    rotationState.quaternionAddRotation (axis, degrees);
 	    rotationState.quaternionToMatrix (rotationMatrix);
-	    emit cubeRotated ();
+	    Q_EMIT cubeRotated ();
 	}
     }
     else if (event != ButtonUp) {
@@ -344,7 +332,7 @@ void MoveTracker::trackSliceMove (int sceneID, const QList<CubeView *> &cubeView
 	    move->slice          = currentMoveSlice;
 	    move->direction      = currentMoveDirection;
 
-	    emit newMove (move);	// Signal Game obj to store this move.
+	    Q_EMIT newMove (move);	// Signal Game obj to store this move.
 	}
 	moveAngle = 0;
 	cube->setMoveAngle (0);
@@ -626,9 +614,8 @@ int MoveTracker::findWhichCube (const int sceneID,
     int    indexV   = -1;
 
     // Find which cube in the current scene is closest to the given position.
-    CubeView * v;
     LOOP (n, cubeViews.size()) {
-        v = cubeViews.at (n);
+        CubeView * v = cubeViews.at (n);
 	if (v->sceneID != sceneID) {
 	    continue;				// Skip unwanted scene IDs.
 	}
